# Vorstellung visibly AI, Einführung und Google Search Integration

> **Source:** [Antonio Blago](https://www.youtube.com/channel/UCoIBDdswc5VViHYPTKd0HwA) | **Duration:** 13:36 | **Published:** 20260202
> **URL:** [https://www.youtube.com/watch?v=LENq2hDKswg](https://www.youtube.com/watch?v=LENq2hDKswg)
> **Views:** 14
> **Tags:** SEOTool, SEOAnalyse, ProjektSetupSEO, GoogleSearchConsole, IndexingAPI, EEATAnalyse, SEOCopilot, KeywordAnalyse, SERPAnalyse, SEOWorkflow

In diesem Video zeige ich dir, wie du in Visibly AI ein Projekt korrekt anlegst, konfigurierst und welche Funktionen dir danach direkt zur Verfügung stehen.

Anmeldung mit 500 gratis Credits: https://visibly-ai.com

Du bekommst einen praxisnahen Rundgang durch das komplette Setup:
von der Registrier...

---

## Table of Contents

- [<Untitled Chapter 1>](#untitled-chapter-1-00:00-00:01)
- [Einstieg: Projekt anlegen & Account-Übersicht](#einstieg-projekt-anlegen-account-bersicht-00:01-00:14)
- [Einstellungen: Google Search Console, Indexing & CoPilot](#einstellungen-google-search-console-indexing-copilot-00:14-01:00)
- [Projekte, Tarife & Wettbewerber hinterlegen](#projekte-tarife-wettbewerber-hinterlegen-01:00-01:51)
- [EEAT-Analyse, Projekt-Typ & Webseitenprofil](#eeat-analyse-projekt-typ-webseitenprofil-01:51-03:08)
- [Indexing Checker & Google Indexing API](#indexing-checker-google-indexing-api-03:08-05:50)
- [SEO CoPilot, To-dos & Umsetzungspläne](#seo-copilot-to-dos-umsetzungsplne-05:50-09:27)
- [API-Keys, Exporte & weitere Tools](#api-keys-exporte-weitere-tools-09:27-13:36)

---

### <Untitled Chapter 1> (00:00 - 00:01)

zeigen, wie du ganz einfach ähm deine

---

### Einstieg: Projekt anlegen & Account-Übersicht (00:01 - 00:14)

zeigen, wie du ganz einfach ähm deine Projekte anlegen kannst als ersten Schritt und in den Settings dann hinterlegen kannst, dass du Google Search Konsole verbinden kannst, Fragen stellen kannst, Indexierung prüfen kannst und weitere SEO Pilot Funktion.

---

### Einstellungen: Google Search Console, Indexing & CoPilot (00:14 - 01:00)

stellen kannst, Indexierung prüfen kannst und weitere SEO Pilot Funktion. Genau. Lass uns gerne reinstarten. Vorab äh einfach registrieren unter Antonio Blago.com Register äh und dann einfach den Optin Prozess verfolgen und dann kommst du dann hier zu dieser Accountersicht und äh hier kannst du auch dann deine Projekte verwalten und auch anlegen. Also freie oder kostenlose User können ein kostenloses Projekt hier anlegen. Standarduser bis zu drei Projekten. Ähm und genau, dann kannst du hier auch ähm deine Konkurrenten hinterlegen, welche dann auch äh wöchentlich ähm oder

---

### Projekte, Tarife & Wettbewerber hinterlegen (01:00 - 01:51)

dann auch äh wöchentlich ähm oder monatlich, je nachdem in dein Einstellung äh ist ähm bekommst du dann auch so eine Übersicht äh zu dem EAT Verlauf und ähm kannst dann noch hier in Einstellungen dann ähm de Projekt hinterlegen, äh sagen, wie häufig die EAT Analyse durchgeführt werden soll. Wöchentlich zwei wöchentlich alle äh jeden Monat nur. Ähm und dann kannst du auch äh maximale Seitenanzahl definieren. Ähm dann kannst du hier in deinem Projektprofil auch dein Projekttypen hinterlegen. Ist das Local SEO E-Commerce Agentur? Ähm, dann welch ist deine Zielgruppe, was deine Rolle, Contentsprache, Seowissen. Ähm, und dann hast du auch hier noch so ein Webseitenprofil. Das

---

### EEAT-Analyse, Projekt-Typ & Webseitenprofil (01:51 - 03:08)

Seowissen. Ähm, und dann hast du auch hier noch so ein Webseitenprofil. Das kannst du auch mit dem äh Crawler hier automatisch hinterlegen. Und ähm dann kannst du hier schon äh hier alle möglichen äh Dinge hinterlegen. Hat gerade mal 2 Sekunden gedauert und äh genau bekommst du auch E-Mailbenachrichtigung, wenn dein EAT Score äh zu gering ist. Ähm, dann kannst du hier auch äh deine Google Search Konsole hinterlegen. Ähm, genau. Und ähm das kannst du dann nutzen für den Indexing Checker und Revenue Analyse etc. pp. Genau, das habe ich jetzt mal gespeichert. Und ähm was auch spannend ist, du kannst äh hier äh dann auch in deinem Indexing äh Checker, also die Google Indexing äh API nutzen. Ähm was was vorher äh manuell gemacht worden ist, sehr äh langwierig. kannst jetzt hier einfach äh hinterlegen. Musst du einfach nur äh hier die Einstellung gehen, Google Search Konsole ähm verbinden, dann kannst du auch Auto Submit hinterlegen. Also, wenn du jetzt z.B. neue URLs hast in deiner Sitemap,

---

### Indexing Checker & Google Indexing API (03:08 - 05:50)

Submit hinterlegen. Also, wenn du jetzt z.B. neue URLs hast in deiner Sitemap, ähm die dann automatisch eingereicht werden ähm täglich, wöchentlich monatlich, je nachdem du willst. Ähm genau täglich ist nur für Pro oder Agency möglich. Ähm und dann bekommst du auch eine automatische E-Mailbenachrichtigung über deine Indexierung. Ähm genau das kann ich dir dann auch noch mal zeigen, wie das aussieht. Ähm, genau. Ich zeige hier mal ganz kurz. Genauso ähm bekommst du dann auch eine E-Mail und ähm genau, dann kannst du hier die Seiten laden ähm über die Synchronisierungsbutton und und dann lädt ihr alle deine URLs hier in äh die äh Zeitmap und ähm genau jetzt hat er hier 95 URLs gefunden und jetzt ähm könnte ich die auch alle prüfen lassen ähm ob sie indexiert worden sind. Ähm also bis 100 URLs prüft er es hier so in dieser Live Ansicht. Ähm und alles darüber wird dann in so eine Art ähm Indexing Job hinterlegt, ähm was dann nachts passiert, weil es natürlich höhere Rechenleistungen ist. Genau. Und man sieht jetzt hier im Hintergrund, wie diese ganzen URLs auch prüft. Ähm, genau. Werden wir äh können wir hier noch weitermachen äh mit den ganzen Funktionen ähm vom äh Copilot. Ähm genau, du hast hier noch die Funktion äh Google zu connecten. Ähm das habe ich hier quasi äh schon gemacht. Ähm, genau. Und äh du kannst auch ähm die Projekte, wie gesagt, hier verwalten. Ähm und äh kannst hier auch so Art Tod-Doos hinterlegen. Ähm, also wenn du jetzt z.B. die EAT Analyse durchgelaufen hast, ähm kann man hier Tod-Doos synchronisieren und ähm genau dann erhält man hier die Tod-Doos. Man kann auch den Copilot fragen, ähm wenn es jetzt z.B. Fragen gibt äh zu den zu den Themen und dann kannst du auch automatisch hier ähm Hilfe bekommen vom Copilot, wenn du

---

### SEO CoPilot, To-dos & Umsetzungspläne (05:50 - 09:27)

kannst du auch automatisch hier ähm Hilfe bekommen vom Copilot, wenn du nicht weiter weißt. Genau. Also, er hat jetzt z.B. will die Anfrage behalten, warum ähm er keine persönlichen Erfahrung in meinen Inhalten sieht und wie ich das verbessern kann. Und ähm dann redt er mir z.B. hier äh was warum es kritisch ist und dann so ein Umsetzungsplan ähm z.B. dass ich z.B. durch Blogartikel gehen kann und äh so äh persönliche Erfahrungen hinzufügen kann. Ähm und genau einfach nicht äh so so Phrasen, ich biete SEO für E-Commerce, sondern in den letzten Jahren habe ich 5 Jahre äh über 50 E-Commerce Shops dabei geholfen. Ähm blablablablabla. Ähm genau. Case Studies sind auf jeden Fall auch immer sehr wichtig. Ähm, genau. Dann hier auch äh so Lessen Learn behind the scenes, Tool, Tool Tests etc. Äh, genau. Und so kann er dir auch konkret weiterhelfen. Genau. Der Status ist momentan bei 46 URLs. Ähm, genau. Da können wir noch mal hier SEO Copilot weitermachen. Ähm, da hast du natürlich auch die Möglichkeit äh dein dein Projekt äh zu verbinden und ähm über hier die Projekt äh über das Projektdashboard und äh dann siehst du auch hier deine ganzen letzten Gespräche. Ähm genau. kannst ja auch Quick Actions durchführen, ähm die auch passend zu deinem Thema sind, also zu deinem Profil. Ähm genau. Genau. Auch was wirklich cool ist, ich habe hier äh auch API Keys. Ähm also du kannst äh über den äh über das Tool hinaus kannst du hier die EVI Keys nutzen und z.B. in äh Chat GPT ein Custom GPT erstellen, um dann ähm so deine Links in dem Custom GPT äh zu überprüfen, also wirklich Live Überprüfung. Ähm und äh hier steht es auch noch mal, wie du das äh Custom äh machst und ähm das auf jeden Fall auch sehr hilfreich. Genau. Alle Daten äh sind generell über hier eine 128 Bit Verschlüsselung gespeichert. Also ist sehr sicher. Ähm dann verwenden wir die äh zusätzlichen Verschlüsselungen und ähm genau ansonsten Right. Genau. Jetzt sehen wir, dass er fertig ist hier und äh die ganzen Überprüfung gemacht hat und ähm muss ich noch mal hier neu laden. Ähm genau. Und dann sieht man auch hier, was jetzt indexiert worden ist, was nicht indexiert ist. Gecrawlet, eingereicht, ausstehend. Ähm hat man natürlich auch hier alle Klicks noch ähm und Impression. Ähm, genau. Und äh du kannst auch jederzeit dann ähm kriegst auch eine E-Mail. Ähm genau. Beim Seocopilot hast du auch die

---

### API-Keys, Exporte & weitere Tools (09:27 - 13:36)

dann ähm kriegst auch eine E-Mail. Ähm genau. Beim Seocopilot hast du auch die Möglichkeit ähm so äh diese ähm API von Data for Zero auch separat zu nutzen. Ähm und z.B. wir hier äh so ein Organic Traffic Snapshot zu beekommen. Also z.B. kannst du jetzt hieray.com äh nutzen und ähm dann äh die Analyse dazu sehen, also wie viel Traffic jetzt äh Poray hat ähm oder irgendwie eine andere Seite. Genau, du kannst auch historische Daten sehen von 5 Jahren. Äh, du kannst Keywords für deine Seite analysieren, ähm deine Mitbewerber und auch äh Seiten noch mal einfach crawlen und auf Onpage äh Analysen äh prüfen. Ähm und deine ganzen Daten siehst du auch immer hier quasi. Ähm, das haben wir gerade gemacht und äh kannst du auch jederzeit hier dann exportieren. Ähm, genau. Excel oder Jason. Genau. Ansonsten habe ich ja auch noch hier andere spannende Tools hinterlegt. Ähm, diesen EAT Analyser, wo du ja deine Seite auf EAT prüfen lassen kannst. Also entweder wöchentlich in deinen Projekten oder auch hier ähm äh getrennt von deinen Projekten. Dann habe ich hier noch den Query Fanout Coverage äh Report. Also, du hast halt die Möglichkeit ähm dadurch ähm, dass AI ja deine Seite ähm referenzieren äh soll, ähm musst du gucken, dass dein dein Themen oder dein Keyword auch auf deine Seite ähm zitierfähig ist. Und das prüft halt dieser Query Fanout äh äh Tool. Ähm und dann erhältst du da auch äh eine Empfehlung äh was du besser schreiben sollst. Z.B. habe ich das jetzt hier mal äh für eine Seite von mir gemacht, ähm die dann ähm jetzt analysiert wird im Hintergrund und dann erhältst du die Ergebnisse. Genau. Ist jetzt äh fertig. Wie wir sehen, äh hat die Ei da nichts dran auszusetzen. Ähm man sieht auch hier die Überschriftenstruktur. Dann sieht man hier, welche besten Matches gab es. Ähm genau extra Topics, also Themen. Und dann kannst du auch jeweils immer äh das Exportieren oder das Markerum nutzen und die AI auffragen, ähm was es z.B. besser schreiben soll. Ähm genau das ist auch möglich. Genau. Ansonsten ähm kannst du hier ein Abonnement auch abschließen oder per Credits einfach nur zahlen, äh wenn du kein Abonnement willst. Ähm genau. Also im Standard Paket sind 2500 Credits drin. Äh im Pro ähm 10.000, im Agency 50.000. Ähm und genau, du hast äh auch die Möglichkeit, die ähm Credits separat einfach zu erwerben. Äh einfach hier über äh auch Starterpaket, Proaket und Agency Paket. Genau. Und die werden dann automatisch auf deinen Account berechnen. Genau. Alles klar. Ich hoffe ähm ich hoffe das Video hat dir einigermaßen geholfen äh ein Überblick zu bekommen und ich werde noch weitere Videos machen, um dir die Funktion besser nahez bringen. Mach's gut. Co?

---


*Transcript source: youtube_auto_generated*
*Confidence: 80%*